==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/uk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Інформація про процесор недоступна",
    "CPU Usage:" : "Використання CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Середнє навантаження: {percentage} % ({load}) за останню хв.",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) за останню хв.\n{last5MinutesPercentage} % ({last5Minutes}) за останні 5 хв.\n{last15MinutesPercentage} % ({last15Minutes}) за останні 15 хв.",
    "RAM Usage:" : "Використання ОЗУ:",
    "SWAP Usage:" : "Використання Swap:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Оперативна пам’ять: використовується {memUsageBytes} із {memTotalBytes}",
    "RAM info not available" : "Інформація про оперативну пам'ять недоступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Файл підкачки: використовується {swapUsageBytes} із {swapTotalBytes}",
    "SWAP info not available" : "Інформація про обмін недоступна",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C, щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C, щоб скопіювати.",
    "Unknown" : "Невідомо",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d днів, %2$d годин, %3$d хвилин, %4$d секунд",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d годин, %2$d хвилин, %3$d секунд",
    "System" : "Система",
    "Monitoring" : "Моніторинг",
    "Monitoring app with useful server information" : "Застосунок моніторингу з корисною інформацією про сервер",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Надає корисну інформацію про сервер, таку як навантаження ЦПУ, використання пам'яті, використання диску, кількість користувачів тощо.",
    "Operating System:" : "Операційна система:",
    "CPU:" : "ЦП:",
    "threads" : "нитки",
    "Memory:" : "Пам'ять:",
    "Server time:" : "Час сервера:",
    "Uptime:" : "Час роботи:",
    "Temperature" : "Температура",
    "Load" : "Навантаження",
    "Memory" : "Пам'ять",
    "Disk" : "Диск",
    "Mount:" : "Точка монтування:",
    "Filesystem:" : "Файлова система:",
    "Size:" : "Розмір:",
    "Available:" : "Доступно:",
    "Used:" : "Використовується:",
    "Files:" : "Файлів:",
    "Storages:" : "Сховищ:",
    "Free Space:" : "Вільно:",
    "Network" : "Мережа",
    "Hostname:" : "Ім'я хосту:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Стан:",
    "Speed:" : "Швидкість:",
    "Duplex:" : "Двосторонній обмін:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активні користувачі",
    "Last hour" : "За останню годину",
    "%s%% of all users" : "%s%% від усіх користувачів",
    "Last 24 Hours" : "За останні 24 години",
    "Last 7 Days" : "За останні 7 днів",
    "Last 30 Days" : "За останні 30 днів",
    "Shares" : "Ресурси спільного доступу",
    "Users:" : "Користувачів:",
    "Groups:" : "Груп:",
    "Links:" : "Посилань:",
    "Emails:" : "Ел. адрес:",
    "Federated sent:" : "Надіслано на сусідні сервери:",
    "Federated received:" : "Отримано від сусідніх серверів:",
    "Talk conversations:" : "Розмов Talk:",
    "PHP" : "PHP",
    "Version:" : "Версія:",
    "Memory limit:" : "Обмеження пам'яті:",
    "MB" : "МБ",
    "Max execution time:" : "Максимальний час виконання:",
    "seconds" : "секунд",
    "Upload max size:" : "Макс. розмір завантаження:",
    "OPcache Revalidate Frequency:" : "Частота ревалідації OPcache:",
    "Extensions:" : "Розширення:",
    "Unable to list extensions" : "Не вдалося створити список розширень",
    "PHP Info:" : "Інфо PHP:",
    "Show phpinfo" : "Показати phpinfo",
    "FPM worker pool" : "Набір обробників FPM",
    "Pool name:" : "Назва пулу:",
    "Pool type:" : "Тип пулу:",
    "Start time:" : "Початковий час:",
    "Accepted connections:" : "Прийняті з'єднання:",
    "Total processes:" : "Разом процесів:",
    "Active processes:" : "Активні процеси:",
    "Idle processes:" : "Сплячі процеси:",
    "Listen queue:" : "Черга прослуховування:",
    "Slow requests:" : "Показати запити:",
    "Max listen queue:" : "Макс. черга прослуховування:",
    "Max active processes:" : "Макс. активних процесів:",
    "Max children reached:" : "Макс. досягнуто дочірніх процесів:",
    "Database" : "База даних",
    "Type:" : "Тип:",
    "External monitoring tool" : "Моніторинг сторонніми засобами",
    "Use this end point to connect an external monitoring tool:" : "Точка доступу для під'єднання зовнішніх інструментів моніторингу:",
    "Copy" : "Копіювати",
    "Output in JSON" : "Вихідний звіт у форматі JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Не показувати інформацію про застосунки (показ даних застосунків призведе до надсилання зовнішніх запитів до крамниці застосунків)",
    "Skip server update" : "Не показувати оновлення сервера",
    "To use an access token, please generate one then set it using the following command:" : "Щоби застосувати токен для доступу, спочатку зґенеруйте його, а потім встановіть за допомогою команди:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потім передайте токен з додаванням заголовку \"NC-Token\" під час надсилання запиту за вказаною вище адресою URL.",
    "Unknown Processor" : "Невідомий процесор"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/uk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Інформація про процесор недоступна",
    "CPU Usage:" : "Використання CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Середнє навантаження: {percentage} % ({load}) за останню хв.",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) за останню хв.\n{last5MinutesPercentage} % ({last5Minutes}) за останні 5 хв.\n{last15MinutesPercentage} % ({last15Minutes}) за останні 15 хв.",
    "RAM Usage:" : "Використання ОЗУ:",
    "SWAP Usage:" : "Використання Swap:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Оперативна пам’ять: використано {memUsageBytes} із {memTotalBytes}",
    "RAM info not available" : "Інформація про оперативну пам'ять недоступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "Файл підкачки: використано {swapUsageBytes} із {swapTotalBytes}",
    "SWAP info not available" : "Інформація про обмін недоступна",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C, щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C, щоб скопіювати.",
    "Unknown" : "Невідомо",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d днів, %2$d годин, %3$d хвилин, %4$d секунд",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d годин, %2$d хвилин, %3$d секунд",
    "System" : "Система",
    "Monitoring" : "Моніторинг",
    "Monitoring app with useful server information" : "Застосунок моніторингу з корисною інформацією про сервер",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Надає корисну інформацію про сервер, таку як навантаження ЦПУ, використання пам'яті, використання диску, кількість користувачів тощо.",
    "Operating System:" : "Операційна система:",
    "CPU:" : "ЦП:",
    "threads" : "нитки",
    "Memory:" : "Пам'ять:",
    "Server time:" : "Час сервера:",
    "Uptime:" : "Час роботи:",
    "Temperature" : "Температура",
    "Load" : "Навантаження",
    "Memory" : "Пам'ять",
    "Disk" : "Диск",
    "Mount:" : "Точка монтування:",
    "Filesystem:" : "Файлова система:",
    "Size:" : "Розмір:",
    "Available:" : "Доступно:",
    "Used:" : "Використано:",
    "Files:" : "Файлів:",
    "Storages:" : "Сховищ:",
    "Free Space:" : "Вільно:",
    "Network" : "Мережа",
    "Hostname:" : "Ім'я хосту:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Стан:",
    "Speed:" : "Швидкість:",
    "Duplex:" : "Двосторонній обмін:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активні користувачі",
    "Last hour" : "За останню годину",
    "%s%% of all users" : "%s%% від усіх користувачів",
    "Last 24 Hours" : "За останні 24 години",
    "Last 7 Days" : "За останні 7 днів",
    "Last 30 Days" : "За останні 30 днів",
    "Shares" : "Ресурси спільного доступу",
    "Users:" : "Користувачів:",
    "Groups:" : "Груп:",
    "Links:" : "Посилань:",
    "Emails:" : "Ел. адрес:",
    "Federated sent:" : "Надіслано на сусідні сервери:",
    "Federated received:" : "Отримано від сусідніх серверів:",
    "Talk conversations:" : "Розмов Talk:",
    "PHP" : "PHP",
    "Version:" : "Версія:",
    "Memory limit:" : "Обмеження пам'яті:",
    "MB" : "МБ",
    "Max execution time:" : "Максимальний час виконання:",
    "seconds" : "секунд",
    "Upload max size:" : "Макс. розмір завантаження:",
    "OPcache Revalidate Frequency:" : "Частота ревалідації OPcache:",
    "Extensions:" : "Розширення:",
    "Unable to list extensions" : "Не вдалося створити список розширень",
    "PHP Info:" : "Інфо PHP:",
    "Show phpinfo" : "Показати phpinfo",
    "FPM worker pool" : "Набір обробників FPM",
    "Pool name:" : "Назва пулу:",
    "Pool type:" : "Тип пулу:",
    "Start time:" : "Початковий час:",
    "Accepted connections:" : "Прийняті з'єднання:",
    "Total processes:" : "Разом процесів:",
    "Active processes:" : "Активні процеси:",
    "Idle processes:" : "Сплячі процеси:",
    "Listen queue:" : "Черга прослуховування:",
    "Slow requests:" : "Показати запити:",
    "Max listen queue:" : "Макс. черга прослуховування:",
    "Max active processes:" : "Макс. активних процесів:",
    "Max children reached:" : "Макс. досягнуто дочірніх процесів:",
    "Database" : "База даних",
    "Type:" : "Тип:",
    "External monitoring tool" : "Моніторинг сторонніми засобами",
    "Use this end point to connect an external monitoring tool:" : "Точка доступу для під'єднання зовнішніх інструментів моніторингу:",
    "Copy" : "Копіювати",
    "Output in JSON" : "Вихідний звіт у форматі JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Не показувати інформацію про застосунки (показ даних застосунків призведе до надсилання зовнішніх запитів до крамниці застосунків)",
    "Skip server update" : "Не показувати оновлення сервера",
    "To use an access token, please generate one then set it using the following command:" : "Щоби застосувати токен для доступу, спочатку зґенеруйте його, а потім встановіть за допомогою команди:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потім передайте токен з додаванням заголовку \"NC-Token\" під час надсилання запиту за вказаною вище адресою URL.",
    "Unknown Processor" : "Невідомий процесор"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
